# OData Integration Update: Translation Corrections (May 26, 2025)
### On this page
  * [Background](https://help.sap.com/docs/leanix/ea/odata-integration-update#background)
  * [Upcoming Changes](https://help.sap.com/docs/leanix/ea/odata-integration-update#upcoming-changes)
  * [Affected Fields](https://help.sap.com/docs/leanix/ea/odata-integration-update#affected-fields)


Update your queries to prepare for upcoming changes to translations affecting the OData integration.
**Note**
The changes described here have been implemented on May 26, 2025.
